SonarrCommandHandler_Episode class

Facilitates, encapsulates, and manages individual calls related to episodes within Sonarr.

SonarrCommandHandler_Episode internally handles routing the HTTP client to the API calls.

Constructors

SonarrCommandHandler_Episode(Dio _client)
Create a series command handler using an initialized Dio client.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getEpisode({required int episodeId}) → Future<SonarrEpisode>
Handler for episode/{id}.
getSeriesEpisodes({required int seriesId}) → Future<List<SonarrEpisode>>
Handler for episode?seriesid={id}.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateEpisode({required SonarrEpisode episode}) → Future<SonarrEpisode>
Handler for episode.

Operators

operator ==(Object other) → bool
The equality operator.
inherited